#id_address, #id_geolocation {width: 40em;}  .map_canvas_wrapper {margin-left: 170px;position: relative}  #map {margin-top: 20px;}  .clear-button {position: absolute;z-index: 1;bottom: 10px;left: 10px;height: 30px;width: 30px;border-radius: 50%;border: 5px solid #3d3d3d;box-shadow: 0 2px 2px 0 rgba(0, 0, 0, .4);cursor: pointer;background-image: linear-gradient(to bottom, #fff 0, #e0e0e0 100%);}  .clear-button:before {position: absolute;content: '';width: 2px;height: 15px;background-color: #616161;top: 0;left: 0;bottom: 0;right: 0;margin: auto;transform: rotate(45deg);}  .clear-button:after {position: absolute;content: '';width: 2px;height: 15px;background-color: #616161;top: 0;left: 0;bottom: 0;right: 0;margin: auto;transform: rotate(-45deg);}  .clear-button:hover {background-color: #f5f5f5;background-image: linear-gradient(to bottom, #ebebeb 0, #fff 100%);box-shadow: inset 0 1px #fff, 0 0 0 1px rgba(0, 0, 0, .3), 0 1px 0 1px rgba(0, 0, 0, .4);}